import type { Property } from '../proxy';
import type { TypeMatcher } from './matcher';
type ObjectType = Record<Property, unknown>;
type DeepPartial<T> = T extends ObjectType ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : T;
/**
 * Match any plain object.
 *
 * Object like values, e.g. classes and arrays, will not be matched.
 *
 * @param partial An optional subset of the expected object that will be
 *   recursively matched. Supports nested matchers. Values will be
 *   compared with {@link deepEquals}.
 *
 * @example
 * const fn = mock<(pos: { x: number, y: number }) => number>();
 * when(() => fn(It.isObject({ x: 23 }))).returns(42);
 *
 * fn({ x: 100, y: 200 }) // throws
 * fn({ x: 23, y: 200 }) // returns 42
 *
 * @example
 * It.isObject({ foo: It.isString() })
 */
export declare const isObject: <T extends ObjectType, K extends DeepPartial<T>>(partial?: K | undefined) => TypeMatcher<T>;
export {};
